"""Configuration for the documentation generation of lsdyna-mesh-reader."""

import datetime
import os

# import pyvista
# from sphinx_gallery.sorting import FileNameSortKey

import lsdyna_mesh_reader

# Manage errors
# pyvista.set_error_output_file("errors.txt")
# # Ensure that offscreen rendering is used for docs generation
# pyvista.OFF_SCREEN = True  # Not necessary - simply an insurance policy
# # Preferred plotting style for documentation
# pyvista.set_plot_theme("document")
# pyvista.global_theme.window_size = [1024, 768]
# # Save figures in specified directory
# pyvista.FIGURE_PATH = os.path.abspath("./images/")
# if not os.path.exists(pyvista.FIGURE_PATH):
#     os.makedirs(pyvista.FIGURE_PATH)

# pyvista.BUILDING_GALLERY = True

# -- Project information -----------------------------------------------------

project = "lsdyna-mesh-reader"
year = datetime.date.today().year
if year > 2024:
    copyright = f"2024-{year}, Alex Kaszynski"
else:
    copyright = f"2024, Alex Kaszynski"
author = "Alex Kaszynski"

# The short X.Y version
version = release = lsdyna_mesh_reader.__version__


# -- General configuration ---------------------------------------------------
# html_logo = "./_static/pyvista_logo_sm.png"

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "myst_parser",
    "sphinx.ext.intersphinx",
    "sphinx.ext.autodoc",
    "sphinx.ext.autosummary",
    # "notfound.extension",
    "sphinx_copybutton",
    "numpydoc",
    # "sphinx.ext.extlinks",
]

# any intersphinx mappings
intersphinx_mapping = {
    "python": ("https://docs.python.org/3", None),
    "pyvista": ("https://docs.pyvista.org/", None),
    "numpy": ("https://numpy.org/doc/stable", None),
}


# html_static_path = ["_static"]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = ".rst"

# The master toctree document.
master_doc = "index"

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = "en"

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path .
exclude_patterns = []

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = "sphinx"

# Copy button customization ---------------------------------------------------
# exclude traditional Python prompts from the copied code
copybutton_prompt_text = r">>> ?|\.\.\. "
copybutton_prompt_is_regexp = True


# -- Options for HTML output -------------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "pydata_sphinx_theme"

html_theme_options = {
    "show_prev_next": False,
    "github_url": "https://github.com/akaszynski/lsdyna-mesh-reader",
    "logo": {
        "text": "LS-DYNA Mesh Reader"
        # "image_light": "pyvista_logo_sm.png",
        # "image_dark": "pyvista_logo_sm.png",
    },
}


# -- Options for HTMLHelp output ---------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = "LSDYNA-Mesh-Reader"


# -- Options for LaTeX output ------------------------------------------------

latex_elements = {}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (
        master_doc,
        "lsdyna_mesh_reader.tex",
        "LS-Dyna Mesh Reader Documentation",
        "Alex Kaszynski",
        "manual",
    ),
]


# -- Options for manual page output ------------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [(master_doc, "LS-Dyna Mesh Reader", "LS-Dyna Mesh Reader Documentation", [author], 1)]


# -- Options for Texinfo output ----------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (
        master_doc,
        "LS-Dyna Mesh Reader",
        "LS-Dyna Mesh Reader Documentation",
        author,
        "LS-Dyna Mesh Reader",
        "LS-Dyna Mesh Reader",
        "Miscellaneous",
    ),
]


# -- Extension configuration -------------------------------------------------

# -- Options for todo extension ----------------------------------------------

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = True


# # -- Sphinx Gallery Options
# sphinx_gallery_conf = {
#     # path to your examples scripts
#     "examples_dirs": [
#         "../examples/",
#     ],
#     # path where to save gallery generated examples
#     "gallery_dirs": ["examples"],
#     # Pattern to search for example files
#     "filename_pattern": r"\.py",
#     # Remove the "Download all examples" button from the top level gallery
#     "download_all_examples": False,
#     # Sort gallery example by file name instead of number of lines (default)
#     "within_subsection_order": FileNameSortKey,
#     # directory where function granular galleries are stored
#     "backreferences_dir": None,
#     # Modules for which function level galleries are created.  In
#     "doc_module": "pymeshfix",
#     "image_scrapers": (pyvista.Scraper(), "matplotlib"),
#     "thumbnail_size": (350, 350),
# }


# -- Custom 404 page

notfound_no_urls_prefix = True
